:py:mod:`piel.file_system`
==========================

.. py:module:: piel.file_system


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.file_system.copy_source_folder
   piel.file_system.setup_example_design
   piel.file_system.check_example_design



.. py:function:: copy_source_folder(source_directory: str, target_directory: str)


.. py:function:: setup_example_design(example_name: str = 'simple_design')

   We copy the example simple_design from docs to the `/foss/designs` in the `iic-osic-tools` environment.


.. py:function:: check_example_design(example_name: str = 'simple_design')

   We copy the example simple_design from docs to the `/foss/designs` in the `iic-osic-tools` environment.


